/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.implement;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.*;
import nl.cloudfarming.client.fleet.machine.windows.ImagePanel;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.util.actions.OpenCloseHandler;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
@MultiViewElement.Registration(displayName = "#LBL_Implement_Image",
iconBase = "nl/cloudfarming/client/fleet/implement/widgets16.png",
mimeType = "application/x-agrosense-implement",
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "ImplementImage",
position = 2000)
@NbBundle.Messages("LBL_Implement_Image=Image")
public final class ImplementImageElement extends JPanel implements MultiViewElement {

    private ImplementDataObject obj;
    private Implement implement;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private ImagePanel imagePanel = new ImagePanel();

    public ImplementImageElement(Lookup lkp) {
        obj = lkp.lookup(ImplementDataObject.class);
        implement = obj.getLookup().lookup(Implement.class);
        assert obj != null;
        assert implement != null;

        setLayout(new BorderLayout());

        imagePanel.setImage(implement.getImage());

        implement.addPropertyChangeListener(Implement.PROP_IMAGE, new PropertyChangeListener() {

            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                imagePanel.setImage((ImageIcon) evt.getNewValue());
            }
        });


        ASBodyPanel overviewDecorator = new ASBodyPanel(imagePanel);
        overviewDecorator.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/fleet/implement/widgets16.png", true));
        add(overviewDecorator);

    }

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
        OpenCloseHandler.Event.triggerOpen(obj.getNodeDelegate());
    }

    @Override
    public void componentClosed() {
        OpenCloseHandler.Event.triggerClose(obj.getNodeDelegate());
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(implement.getName());
            tc.setDisplayName(implement.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
