/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.implement.wizard;

import java.util.Calendar;
import java.util.LinkedList;
import java.util.List;
import nl.cloudfarming.client.fleet.implement.ImplementDataService;
import nl.cloudfarming.client.fleet.implement.ImplementManagerImpl;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardFactory;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardOverviewPanel;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardPanel;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardStartPanel;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.fleet.model.MachineProvider;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.WizardDescriptor.Panel;

/**
 *
 * @author Wytse Visser
 */
class ImplementWizardFactory extends MachineWizardFactory {

    public ImplementWizardFactory(Project project) {
        super(project);
    }

    @Override
    public MachineWizardPanel createOverviewPanel() {
        return new MachineWizardOverviewPanel();
    }

    @Override
    public List<Panel<WizardDescriptor>> createInitialPanels() {
        List<WizardDescriptor.Panel<WizardDescriptor>> panels = new LinkedList<>();
        EnterpriseIdProvider eip = getProject().getLookup().lookup(EnterpriseIdProvider.class);
        Implement implement = new Implement(eip, "");
        final int currentYear = Calendar.getInstance().get(Calendar.YEAR);
        implement.setYear(currentYear);
        panels.add(new MachineWizardStartPanel(this, implement));
        return panels;
    }

    @Override
    public Class<? extends MachineDataService> getDataServiceClass() {
        return ImplementDataService.class;
    }

    @Override
    public Class<? extends MachineProvider> getMachineProviderClass() {
        return ImplementManagerImpl.class;
    }

}
